# CM23137UNO

Librería para resolver sistemas de ecuaciones lineales y no lineales utilizando diversos métodos numéricos, como:

- Eliminación de Gauss
- Gauss-Jordan
- Cramer
- Descomposición LU
- Jacobi
- Gauss-Seidel
- Bisección

## Instalación

Puedes instalar la librería usando `pip` directamente desde [PyPI](https://pypi.org):

```bash
pip install CM23137UNO